@@ -1,9 +1,11 @@
+use strict; use warnings;
+
 package DBIx::Connector::Driver::Pg;
 
-use strict;
-use warnings;
-use base 'DBIx::Connector::Driver';
-our $VERSION = '0.56';
+use DBIx::Connector::Driver;
+
+our $VERSION = '0.59';
+our @ISA = qw( DBIx::Connector::Driver );
 
 sub savepoint {
     my ($self, $dbh, $name) = @_;
@@ -21,13 +23,14 @@ sub rollback_to {
 }
 
 1;
+
 __END__
 
-=head1 Name
+=head1 NAME
 
 DBIx::Connector::Driver::Pg - PostgreSQL-specific connection interface
 
-=head1 Description
+=head1 DESCRIPTION
 
 This subclass of L<DBIx::Connector::Driver|DBIx::Connector::Driver> provides
 PostgreSQL-specific implementations of the following methods:
@@ -46,9 +49,9 @@ strongly recommended.
 
 =back
 
-=head1 Authors
+=head1 AUTHORS
 
-This module was written and is maintained by:
+This module was written by:
 
 =over
 
@@ -66,7 +69,7 @@ It is based on code written by:
 
 =back
 
-=head1 Copyright and License
+=head1 COPYRIGHT AND LICENSE
 
 Copyright (c) 2009-2013 David E. Wheeler. Some Rights Reserved.
 
